data = read.csv("pima-indians-diabetes.csv", header = FALSE)

# ----1.----

# Scatter plot
plot(
  main = "Plasma Glucose Concentration vs Age",
  data$V2,
  data$V8,
  xlab = "Plasma Glucose Concentration",
  ylab = "Age",
  col = ifelse(data$V9 == 1, "red", "blue"),
  pch = ifelse(data$V9 == 1, 18, 1)
)
legend(
  "topleft",
  legend = c("Diabetes", "No Diabetes"),
  fill = c("red", "blue"),
  pch = c(18, 1)
)

# ----2.----

model <- glm(V9 ~ V2 + V8, family = binomial, data = data)

predict_reg <- predict(model, data, type = "response")

r = 0.5

predict_reg <- ifelse(predict_reg > r, 1, 0)

# Missclassification rate
missclass = function(X, Xfit) {
  n = length(X)
  return(1 - sum(diag(table(X, Xfit))) / n)
}

missclass_rate = missclass(data$V9, predict_reg)

print(missclass_rate)

plot(
  main = "Plasma Glucose Concentration vs Age (r=0.5)",
  data$V2,
  data$V8,
  xlab = "Plasma Glucose Concentration",
  ylab = "Age",
  col = ifelse(predict_reg == 1, "red", "blue"),
  pch = ifelse(predict_reg == 1, 18, 1)
)

legend(
  "topleft",
  legend = c("Diabetes", "No Diabetes"),
  fill = c("red", "blue"),
  pch = c(18, 1)
)


# ----3.----

theta <- coefficients(model)

get_boundary <- function(x1, theta, r) {
  logit_r <- log(r / (1 - r))
  return((-theta[1] - log((1 - r) / r) - theta[2] * x1) / theta[3])
}

x1 <- seq(min(data$V2), max(data$V2), length.out = 100)

boundary <- sapply(x1, get_boundary, theta = theta, r = r)

lines(x1, boundary, col = "black", lwd = 2)


# ----5.----

data$z1 <- data$V2 ^ 4
data$z2 <- data$V2 ^ 3 * data$V8
data$z3 <- data$V2 ^ 2 * data$V8 ^ 2
data$z4 <- data$V2 * data$V8 ^ 3
data$z5 <- data$V8 ^ 4

model2 <- glm(V9 ~ V2 + V8 + z1 + z2 + z3 + z4 + z5, family = binomial, data = data)

predict_reg2 <- predict(model2, data, type = "response")
predict_reg2 <- ifelse(predict_reg2 > r, 1, 0)

plot(
  main = "Plasma Glucose Concentration vs Age (r=0.5)",
  data$V2,
  data$V8,
  xlab = "Plasma Glucose Concentration",
  ylab = "Age",
  col = ifelse(predict_reg2 == 1, "red", "blue"),
  pch = ifelse(predict_reg2 == 1, 18, 1)
)
legend(
  "topleft",
  legend = c("Diabetes", "No Diabetes"),
  fill = c("red", "blue"),
  pch = c(18, 1)
)

missclass_rate2 = missclass(data$V9, predict_reg2)

print(summary(model2))
print(missclass_rate2)
